require 'pry'
require 'capybara/poltergeist'
require 'nokogiri'
require 'json'
require 'io/console'
require 'terminal-table'
require 'sqlite3'
require 'sequel'

Capybara.register_driver :poltergeist do |app|
  Capybara::Poltergeist::Driver.new(app, {js_errors: false})
end

DB = Sequel.sqlite(File.expand_path(File.dirname(__FILE__) + '/student_progress.db')) # memory database, requires sqlite3

unless DB.table_exists? :lessons 
  DB.create_table :lessons do
    primary_key :id
    String :title
    String :content_type
    String :repo
    String :unit
    String :track_version
  end
end

unless DB.table_exists? :progress_reports 
  DB.create_table :progress_reports do
    primary_key :id
    DateTime :created_at
    String :content
    Integer :cohort_id
  end
end


unless DB.table_exists? :student_reports 
  DB.create_table :student_reports do
    primary_key :id
    DateTime :created_at
    String :current_lab
    Integer :lessons_complete
    Integer :labs_complete
    Integer :progress_report_id
    Integer :student_id
  end
end

unless DB.table_exists? :cohorts 
  DB.create_table :cohorts do
    primary_key :id
    String :name
  end
end

unless DB.table_exists? :students 
  DB.create_table :students do
    primary_key :id
    String :first_name
    String :last_name
    String :github_username
    String :timezone
    Integer :cohort_id
  end
end

unless DB.table_exists? :completed_lessons 
  DB.create_table :completed_lessons do
    primary_key :id
    Integer :lesson_id
  end
end

unless DB[:completed_lessons].columns.include?(:date)
  DB.add_column :completed_lessons, :date, :date
end

unless DB[:cohorts].columns.include?(:periscope_url)
  DB.add_column :cohorts, :periscope_url, :string
end

unless DB[:completed_lessons].columns.include?(:student_id)
  DB.add_column :completed_lessons, :student_id, :integer
end

unless DB[:student_reports].columns.include?(:current_topic_status)
  DB.add_column :student_reports, :current_topic_status, :string
end

require_relative "./student_progress/version"
require_relative "./student_progress/cli"
require_relative "./student_progress/student"
require_relative "./student_progress/cohort"
require_relative "./student_progress/scraper"
require_relative "./student_progress/lesson"
require_relative "./student_progress/topic"
require_relative "./student_progress/unit"
require_relative "./student_progress/student_report"
require_relative "./student_progress/progress_report"
require_relative "./student_progress/progress_importer"
require_relative "./student_progress/completed_lesson"


# module StudentProgress
#   # Your code goes here...
# end
