class StudentProgress::Topic
  attr_accessor :title, :id
  attr_reader :units

  @@all = []

  def self.all 
    @@all
  end

  def self.create_from_hash(hash)
    new(hash).save
  end

  def self.find_by_title(title)
    all.find{|t| t.title == title}
  end

  def initialize(attrs = {})
    attrs.each do |attr, value|
      self.send("#{attr}=", value)
    end
    @units = []
  end

  def save 
    @@all << self 
    self
  end

  def add_unit(unit)
    @units << unit unless @units.include?(unit)
    unit.topic = self unless unit.topic == self
    unit
  end

  def lessons
    @units.map{|u| u.lessons}.flatten
  end

  def lessons_by_unit
    result = {}
    @units.each do |unit|
      result[unit.title] = unit.lessons.map{|l| "#{l.title} - #{l.content_type} (#{l.id})"}
    end
    result
  end

  def summary
    {
      topic: title,
      units: @units.map{|u| u.title},
      lessons: lessons_by_unit,
      readmes: lessons.count{|l| l.content_type == "Readme"},
      labs: lessons.count{|l| l.content_type == "Lab"},
      projects: lessons.count{|l| l.content_type == "Project"}
    }
  end
end