class StudentProgress::Unit
  attr_accessor :title, :id, :topic
  attr_reader :lessons

  @@all = []

  def self.all
    @@all
  end

  def self.create_from_hash(hash)
    new(hash).save
  end

  def initialize(attrs = {})
    attrs.each do |attr, value|
      self.send("#{attr}=", value)
    end
    @lessons = []
  end

  def save 
    @@all << self 
    self
  end

  def add_lesson(lesson)
    @lessons << lesson unless @lessons.include?(lesson)
    lesson.unit = self unless lesson.unit == self
    lesson
  end

  def topic=(topic)
    @topic = topic
    topic.add_unit(self)
  end

  def lessons_by_type
    @lessons.map{|l| "#{l.title} - #{l.content_type} (#{l.id})"}
  end

  def summary
    { 
      topic: topic,
      unit: title,
      lessons: lessons_by_type,
      readmes: @lessons.count{|l| l.content_type == "Readme"},
      labs: @lessons.count{|l| l.content_type == "Lab"},
      projects: @lessons.count{|l| l.content_type == "Project"}
    }
  end
end